NAME

Zuzu - API helpers for evaluating ZuzuScript

SYNOPSIS

use Zuzu qw( zuzu_eval zuzu_evalfile );

my $runtime = zuzu_eval(
  'function hi() { return "hello"; }',
  { deny_modules => [ 'std/io' ] },
);

my $runtime2 = zuzu_evalfile(
  'example.zzs',
  { lib => [ './modules' ] },
);

DESCRIPTION

Provides helper functions for one-shot parsing and evaluation.

FUNCTIONS

zuzu_eval( $script, \%runtime_options )

Parses and evaluates a ZuzuScript source string and returns the result of evaluation.

zuzu_evalfile( $filename, \%runtime_options )

Loads a UTF-8 script file, parses and evaluates it, and returns the result of evaluation.

SEE ALSO

https://zuzulang.org/.

COPYRIGHT AND LICENCE

Zuzu is copyright Toby Inkster.

It is free software; you may redistribute it and/or modify it under the terms of either the Artistic License 1.0 or the GNU General Public License version 2.